#
# spec file for package aws-c-cal
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define library_version 1.0.0
%define library_soversion 0unstable
Name:           aws-c-cal
Version:        0.7.4
Release:        1.1
Summary:        AWS C99 wrapper for cryptography primitives
License:        Apache-2.0
Group:          Development/Libraries/C and C++
URL:            https://github.com/awslabs/aws-c-cal
Source0:        https://github.com/awslabs/%{name}/archive/v%{version}.tar.gz
Patch0:         acc_fix-cmake-modules-path.patch
Patch1:         acc_add-so-version.patch
BuildRequires:  cmake
BuildRequires:  fdupes
BuildRequires:  cmake(aws-c-common)
BuildRequires:  cmake(aws-checksums)
BuildRequires:  pkgconfig(libcrypto)
BuildRequires:  cmake(s2n)
BuildRequires:  ninja
BuildRequires:  pkgconfig

%description
AWS Crypto Abstraction Layer is a C99 wrapper for cryptography primitives.

%package -n lib%{name}%{library_soversion}
Summary:        AWS C99 wrapper for cryptography primitives
Group:          System/Libraries

%description -n lib%{name}%{library_soversion}
AWS Crypto Abstraction Layer is a C99 wrapper for cryptography primitives.

This package contains the dynamically linked library.

%package devel
Summary:        Development files for aws-c-cal library
Group:          Development/Libraries/C and C++
Requires:       lib%{name}%{library_soversion} = %{version}

%description devel
AWS Crypto Abstraction Layer, a C99 wrapper for cryptography primitives.

This package contains the development files.

%prep
%autosetup -p1

%build
%define __builder ninja
%cmake \
    -DCMAKE_BUILD_TYPE=Release
%make_jobs

%check
export LD_LIBRARY_PATH=%{_builddir}/%{name}-%{version}/build
%ctest

%install
%cmake_install

%post -n lib%{name}%{library_soversion} -p /sbin/ldconfig
%postun -n lib%{name}%{library_soversion} -p /sbin/ldconfig

%files -n lib%{name}%{library_soversion}
%doc README.md
%license LICENSE
%{_libdir}/*.so.%{library_soversion}
%{_libdir}/*.so.%{library_version}

%files devel
%{_libdir}/cmake/
%{_libdir}/*.so
%{_includedir}/*

%changelog
* Mon Aug 26 2024 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- Update to version 0.7.4
  * OpenSSL Runtime and Compile Time Mismatch Fix by @waahm7 in (#198)
- from version 0.7.3
  * Update MacOS CI to arm64 by @waahm7 in (#196)
  * Use prebuilt aws-lc by @sfod in (#197)
* Fri Jul 19 2024 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- Update to version 0.7.2
  * CI for AWS-LC-FIPS by @graebm in (#192)
  * Fix FreeBSD CI to install default python packages
    by @TingDaoK in (#193)
  * Revert "Revert "Implement runtime check on libcrypto linkage (#186)"
    by @TingDaoK in (#195)
* Thu Jul  4 2024 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- Update to version 0.7.1
  * Revert lc pin by @DmitriyMusatkin in (#190)
  * Revert "Implement runtime check on libcrypto linkage (#186)"
    by @graebm in (#191)
* Wed Jun 26 2024 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- Update to version 0.7.0
  * clang-format 18 by @graebm in (#187)
  * Implement runtime check on libcrypto linkage
    by @WillChilds-Klein in (#186)
  * Pin AWS-LC until it's fixed for manylinux1
    by @graebm in (#188)
  * Make AES GCM more consistent cross platform
    by @DmitriyMusatkin in (#189)
* Fri May 31 2024 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- Update to version 0.6.15
  * Fix inccorect export of aws_symmetric_cipher_get_state by @sbiscigl in (#185)
* Wed May 22 2024 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- Update to version 0.6.14
  - Fix inccorect export of aws_symmetric_cipher_get_state by @sbiscigl in (#185)
* Mon May 13 2024 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- Update to version 0.6.13
  * Fix handling of empty plaintext for AES by @DmitriyMusatkin in (#183)
  * Adds a way to keep a more detailed state of a symetric cipher
    by @sbiscigl in (#184)
- from version 0.6.12
  * CI test: Apple: explicitly include & link to CoreFoundation
    by @jmklix in (#181)
  * Move aws-lc shutdown to destructor from cleanup
    by @DmitriyMusatkin in (#182)
* Mon Apr 15 2024 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- Update to version 0.6.11
  * Not install tests stuff by @TingDaoK in (#177)
  * chore(ci): Performance boost to OpenBSD CI jobs by @knightjoel in (#179)
  * CI job for FreeBSD by @knightjoel in (#178)
  * Fix: Use buffer without memory allocation by @alfred2g in (#180)
- Drop aws-c-cal package as upstream no longer installs the binaries
* Tue Feb 20 2024 Dominique Leuenberger <dimstar@opensuse.org>
- Use %%autosetup macro. Allows to eliminate the usage of deprecated
  %%patchN.
* Mon Feb 19 2024 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- Update to version 0.6.10
  * Update bot permissions by @jmklix in (#172)
  * Fix a bunch of places we forget to aws_raise_error() by @graebm in (#176)
  * Consistently use lowercase for Windows libraries by @giordano in (#161)
  * Allows cmake to force crypto linkage. by @sbiscigl in (#175)
* Tue Nov 21 2023 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- Update to version 0.6.9
  * Use AWS_APPSTORE_SAFE cflag to gate access to
    private APIs by @graebm in (#171)
- from version 0.6.8
  * Stop using private CommonCrypto APIs on iOS by @graebm in (#170)
- from version 0.6.7
  * Fix OpenSSL 3 tests by @DmitriyMusatkin in (#169)
* Tue Oct 17 2023 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- Update to version 0.6.6
  * More consistent signature mismatch error on mac by @DmitriyMusatkin in (#167)
  * Consistent signature validation for short signatures by @DmitriyMusatkin in (#168)
- from version 0.6.5
  * Missing salt define by @DmitriyMusatkin in (#165)
- from version 0.6.4
  * Fix build against openssl 1.0.2 by @DmitriyMusatkin in (#164)
- from version 0.6.3
  * Added workflow for handling answerable discussion by @yasminetalby in (#156)
  * Fix aws-c-cal-config.cmake by @graebm in (#158)
  * Be more explicit on int format in DER by @DmitriyMusatkin in (#160)
  * RSA support by @DmitriyMusatkin in (#159)
  * Fix for byo crypto compile and add ci for it by @TingDaoK in (#162)
  * Use fake pub key by @TingDaoK in (#163)
* Wed Aug 30 2023 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- Update to version 0.6.2
  * Minor CMakelists.txt cleanup by @graebm in (#155)
  * Explicit Private for target_link_libraries by @waahm7 in (#157)
* Tue Jul 25 2023 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- Update to version 0.6.1
  * Stop using memset(), use byte-buf helper function instead. by @graebm in (#154)
* Mon Jul  3 2023 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- Update to version 0.6.0
  * Update time to ancient (#150)
  * Cleanup aws-lc thread locals and thread
    local key on library shutdown (#152)
* Tue May 16 2023 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- Update to version 0.5.27
  * Support BoringSSL by @DmitriyMusatkin in (#148)
  * Fix warnings in public headers by @waahm7 in (#149)
* Wed Apr 26 2023 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- Update to version 0.5.26
  * Fixed CTR mode on OpenSSL not generating an empty counter
    by @JonathanHenson in (#147)
- from version 0.5.25
  * Add Github templates and bots by @jmklix in (#143)
  * Unpin awslc by @TingDaoK in (#144)
  * Fix for osx deployment target 10.9 by @waahm7 in (#145)
  * Added validation for key and iv sizes. by @JonathanHenson in (#146)
* Tue Apr 18 2023 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- Update to version 0.5.24
  * Correctly detect macOS version by @JonathanHenson in (#140)
  * Handle OpenSSL 1.0 on cipher reset correctly
    by @JonathanHenson in (#141)
- from version 0.5.23
  * Minor Bug fix in keywrap buffer management that broke on
    statically allocated buffers by @JonathanHenson in (#139)
- from version 0.5.22
  * CI job for OpenBSD by @knightjoel in (#134)
  * Pull in aws-lc during builder builds on OpenBSD
    by @knightjoel in (#135)
  * Remove sanitizer blacklist by @DmitriyMusatkin in (#137)
  * Pin version of aws-lc by @DmitriyMusatkin in (#138)
  * Added 256-bit AES with CBC, CTR, GCM, and Keywrap
    Modes by @JonathanHenson in (#136)
* Fri Mar  3 2023 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- Update to version 0.5.21
  * Fix build on OpenBSD by @knightjoel in (#133)
* Fri Oct 14 2022 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- Update to version 0.5.20
  * Fix dynamic loading of AWS-LC by @jeking3 in (#129)
* Thu Sep  1 2022 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- Update to version 0.5.19
  * Double fallback for load target by @TingDaoK in (#123)
- from version 0.5.18
  * CI to run ECC signature verifier tool on cross-platform
    data set by @bretambrose in (#118)
  * Apple assert fix by @graebm in (#121)
* Wed May 18 2022 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- Update to version 0.5.17
  * Find OpenSSL package from system by @serzhick in (#114)
- from version 0.5.16
  * Remove AWS:: prefix from crypto module used from cmake path
    in case of IN_SOURCE_BUILD by @serzhick in (#112)
- from version 0.5.15
  * Fix an issue where windows implementations of ecdsa wasn't
    properly trimming padding from sha256 signature.
* Tue Mar  1 2022 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- Update to version 0.5.14
  + Fixed build failure from previous release.
  * Fixed memory leak in unit test. (#106)
- from version 0.5.13
  + Fix aws-lc targets.
  * Properly use cmake target exports for libcrypto. (#104)
* Sat Oct 16 2021 Jan Engelhardt <jengelh@inai.de>
- Use cmake()/pkgconfig() as buildrequires. Update descriptions.
- Replace %%-bin subpackage by just %%, and lib%%-devel by %%-devel.
* Mon Oct 11 2021 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- Update to version 0.5.12
  + Removed sha256_profile binary from common build path
  * Only build sha256_profile if BUILD_TESTING is enabled (#101)
* Mon Jun 21 2021 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- Update to version 0.5.11
  + Logging updates
  * Move libcrypto symbol resolution output to logging calls
- from version 0.5.10
  + BYO_CRYPTO updates for Sigv4a
  * Updated some ecc key API functions to have BYO_CRYPTO-conditional implementations
- from version 0.5.9
  + Support in-source build with AWS-LC
  * Instead of always searching for a pre-installed libcrypto, now provide the option
    to use the crypto target to do the link. It's useful for the in-source build, where
    we will not install libcrypto, instead, we build aws-lc (for libcrypto) before building
    aws-c-cal.
- from version 0.5.8
  + SHA1 Hash Support
  * Adding support for SHA1.
- from version 0.5.7
  + Don't run aws-lc's codegen at build time
  * Disable aws-lc's codegen. (#90)
    Background: aws-lc uses codegen to create some of its source files, and it runs these generators
    if the user's machine has Go and Perl installed. However, up-to-date versions of the generated
    files are already committed to the repo, so it's not necessary for users to run codegen on their
    machines. This codegen has led to unexpected issues (ex: failure due to network access at build
    time) so let's just turn it off and reduce unnecessary complexity.
- from version 0.5.6
  + OpenSSL detection fixes
  * OpenSSL/libcrypto fixes and CI (#88)
  * Additional fixes from OpenSSL testing
  * Added diagnostics for libcrypto usage
  * Only allow openssl variant on linux
  * Fixed versioning of builder in builds that left it out
  * Updated to builder v0.8.14 for variants support
- from version 0.5.5
  + Restored OpenSSL detection and improved robustness
  * Fixes to OpenSSL probing from testing (#87)
  * Fixed static resolution pass to be exhaustive before attempting dynamic pass
  * Made logging consistent between API resolution functions
- from version 0.5.4
  + Fix aws-lc builds when shared libs is ON
  * Propagates the BUILD_SHARED_LIBS settings downstream to the aws-lc build
- from version 0.5.3
  + Improved ECC support
  * Fix some ECC key generation tests
  * Update Windows system dependencies to include Ncrypt to allow for ECC imports
- from version 0.5.2
  + aws-lc.cmake skips libssl, builds only libcrypto
  * aws-lc.cmake skips libssl, builds only libcrypto (#74)
- from version 0.5.1
  + Added Bring your own crypto support for unix platforms.
  * Add CI jobs for shared-libs (#69)
  * Also fix windows-vc14 (x86) job so it actually uses vc14, and actually builds x86
- from version 0.5.0
  + Now using aws-lc instead of libcrypto on UNIX platforms
  * Integration of AWS LC as crypto implementation on UNIX platforms (#67)
  * Make Unix platforms build with AWS-LC
  * Disabled fail-fast on matrix tests
  * Temporarily remove auth downstream until auth is updated
  * Deleted libcrypto depedency:
  * Added aws-lc as dependency
  * Added support for lib64 dirs on RH variants
  * Consume LibCrypto::Crypto the same way s2n does
  * Removed broken shared-libs job
* Thu Nov 26 2020 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- Initial build
  + Version 0.4.5
